PropKey

Enum PropKey 

pub enum PropKey {
    CompKey(CompKey),
    FpdKey(FpdKey),
}
Keys for accessing specific property values from MixProperties via MixProperties::get()

This enum wraps both CompKey and FpdKey to allow accessing all properties from a single interface, which is helpful in downstream applications, to have a single flattened list of keys. There are From implementations for both key types to facilitate easy conversion.

Example

use sci_cream::{CompKey, FpdKey, PropKey, MixProperties};
let mix_props = MixProperties::empty();
assert_eq!(mix_props.get(CompKey::MilkFat.into()), 0.0);
assert_eq!(mix_props.get(FpdKey::FPD.into()), 0.0);

Variants



CompKey(CompKey)



FpdKey(FpdKey)

FpdKey for FPD properties from MixProperties::fpd