pub enum FpdKey {
FPD,
ServingTemp,
HardnessAt14C,
}Expand description
Keys for accessing specific composition values from an FPD via FPD::get()
This exists largely to mirror how CompKey and Composition::get() work, which is helpful
in downstream applications, e.g. to have a single flattened list of keys for properties; see
PropKey and MixProperties::get().
Variants
FPD
Freezing Point Depression (FPD) in °C
This denotes the temperature at which a mix begins to freeze, which is typically depressed
to a temperature lower than 0°C, that at which pure water freezes. This value is the first
point on the frozen water curve at which the
x-axis is 0% frozen water; see CurvePoint and Curves::frozen_water.
ServingTemp
Temperature at which the mix reaches a desired serving hardness
This is the y-value (temperature) intersection of the hardness FPD
curve in Curves at a specific hardness
value, typically 70-75% - defined by SERVING_TEMP_X_AXIS in current calculations.